@@ -73,12 +73,22 @@ ev_application_register_service (EvApplication *application)
 						  DBUS_PATH_DBUS,
 						  DBUS_INTERFACE_DBUS);
 
+#if DBUS_VERSION >= 60	
 	if (!org_freedesktop_DBus_request_name (driver_proxy,
                                         	APPLICATION_SERVICE_NAME,
+						DBUS_NAME_FLAG_DO_NOT_QUEUE,
+						&request_name_result, &err)) {
+		g_warning ("Service registration failed.");
+		g_clear_error (&err);
+	}
+#else
+	if (!org_freedesktop_DBus_request_name (driver_proxy,
+						APPLICATION_SERVICE_NAME,
 						0, &request_name_result, &err)) {
 		g_warning ("Service registration failed.");
 		g_clear_error (&err);
 	}
+#endif	
 
 	if (request_name_result == DBUS_REQUEST_NAME_REPLY_EXISTS) {
 		return FALSE;
@@ -304,7 +314,9 @@ ev_application_shutdown (EvApplication *application)
 		application->recent_model = NULL;
 	}
 
+	g_free (application->last_chooser_uri);
 	g_object_unref (application);
+	
 	gtk_main_quit ();
 }
 
@@ -376,4 +388,14 @@ void ev_application_save_toolbars_model (EvApplication *application)
 				 application->toolbars_file, "1.0");
 }
 
+void ev_application_set_chooser_uri (EvApplication *application, gchar *uri)
+{
+	g_free (application->last_chooser_uri);
+	application->last_chooser_uri = g_strdup (uri);
+}
+
+const gchar* ev_application_get_chooser_uri (EvApplication *application)
+{
+	return application->last_chooser_uri;
+}
 
