@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-page-action.c,v 1.21 2005/06/19 13:10:20 nshmyrev Exp $
+ *  $Id: ev-page-action.c,v 1.26 2005/12/28 13:37:40 nshmyrev Exp $
  */
 
 #include "config.h"
@@ -181,12 +181,13 @@ page_changed_cb (EvPageCache        *page_cache,
 	g_assert (proxy);
 	
 	if (page_cache != NULL && page >= 0) {
-	
+		gchar *page_label;
+
 		gtk_entry_set_width_chars (GTK_ENTRY (proxy->entry), 
 					   CLAMP (ev_page_cache_get_max_label_chars (page_cache), 
-					   4, 12));	
+					   6, 12));	
 		
-		gchar *page_label = ev_page_cache_get_page_label (page_cache, page);
+		page_label = ev_page_cache_get_page_label (page_cache, page);
 		gtk_entry_set_text (GTK_ENTRY (proxy->entry), page_label);
 		gtk_editable_set_position (GTK_EDITABLE (proxy->entry), -1);
 		g_free (page_label);
@@ -297,7 +298,7 @@ build_new_tree_cb (GtkTreeModel *model,
 			    EV_DOCUMENT_LINKS_COLUMN_LINK, &link,
 			    -1);
 
-	if (link && ev_link_get_link_type (link) == EV_LINK_TYPE_PAGE) {
+	if (link && ev_link_get_page (link) >= 0) {
 		GtkTreeIter filter_iter;
 
 		gtk_list_store_append (GTK_LIST_STORE (filter_model), &filter_iter);
@@ -478,7 +479,8 @@ update_model (EvPageAction *page, GParamSpec *pspec, EvPageActionWidget *proxy)
 						    (GtkCellLayoutDataFunc) display_completion_text,
 						    proxy, NULL);
 		gtk_entry_set_completion (GTK_ENTRY (proxy->entry), completion);
-
+		
+		g_object_unref (completion);
 		g_object_unref (model);
 	}
 }
@@ -651,7 +653,7 @@ ev_page_action_class_init (EvPageActionClass *class)
 	signals[ACTIVATE_LABEL] = g_signal_new ("activate_label",
 					        G_OBJECT_CLASS_TYPE (object_class),
 					        G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-					        G_STRUCT_OFFSET (EvPageActionClass, activate_link),
+					        G_STRUCT_OFFSET (EvPageActionClass, activate_label),
 					        NULL, NULL,
 					        ev_marshal_BOOLEAN__STRING,
 					        G_TYPE_BOOLEAN, 1,
